@@ -1,12 +1,6 @@
 use std::rc::Rc;
 
-use crate::{
-    ErrorKind,
-    ImageFlags,
-    ImageInfo,
-    ImageSource,
-    PixelFormat,
-};
+use crate::{ErrorKind, ImageFlags, ImageInfo, ImageSource, PixelFormat};
 
 use glow::HasContext;
 
