@@ -1,40 +1,20 @@
 use std::cell::RefCell;
 use std::ffi::OsStr;
 use std::fs;
-use std::hash::{
-    Hash,
-    Hasher,
-};
+use std::hash::{Hash, Hasher};
 use std::ops::Range;
 use std::path::Path as FilePath;
 use std::rc::Rc;
 
-use fnv::{
-    FnvBuildHasher,
-    FnvHashMap,
-    FnvHasher,
-};
-use generational_arena::{
-    Arena,
-    Index,
-};
+use fnv::{FnvBuildHasher, FnvHashMap, FnvHasher};
+use generational_arena::{Arena, Index};
 use lru::LruCache;
 
 use unicode_bidi::BidiInfo;
 use unicode_segmentation::UnicodeSegmentation;
 
 use crate::{
-    Canvas,
-    Color,
-    ErrorKind,
-    FillRule,
-    ImageFlags,
-    ImageId,
-    ImageInfo,
-    Paint,
-    PixelFormat,
-    RenderTarget,
-    Renderer,
+    Canvas, Color, ErrorKind, FillRule, ImageFlags, ImageId, ImageInfo, Paint, PixelFormat, RenderTarget, Renderer,
 };
 
 mod atlas;
@@ -144,7 +124,6 @@ pub(crate) struct RenderedGlyph {
     bearing_y: i32,
     atlas_x: u32,
     atlas_y: u32,
-    padding: u32,
     color_glyph: bool,
 }
 
@@ -935,7 +914,6 @@ impl GlyphAtlas {
             atlas_x: dst_x as u32 + GLYPH_MARGIN,
             atlas_y: dst_y as u32 + GLYPH_MARGIN,
             texture_index: dst_index,
-            padding: padding - GLYPH_MARGIN,
             color_glyph,
         };
 
